add missing comment to wfstack.c
[urcu.git] / urcu.h
diff --git a/urcu.h b/urcu.h
index 69c06e409ddaf2bb95d96d27ae6d9369b777d40b..c6c54e7c7c3bcbc83d88b279e20ab35f64a0806f 100644 (file)
--- a/urcu.h
+++ b/urcu.h
@@ -6,7 +6,7 @@
  *
  * Userspace RCU header
  *
- * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
+ * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  * Copyright (c) 2009 Paul E. McKenney, IBM Corporation.
  *
  * LGPL-compatible code should include this header with :
  */
 #include <urcu-pointer.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif 
+
 /*
  * Important !
  *
@@ -88,8 +92,12 @@ extern void rcu_register_thread(void);
 extern void rcu_unregister_thread(void);
 
 /*
* Explicit urcu initialization, for "early" use within library constructors.
  */
-extern void urcu_init(void);
+extern void rcu_init(void);
+
+#ifdef __cplusplus 
+}
+#endif
 
 #endif /* _URCU_H */
This page took 0.023186 seconds and 4 git commands to generate.
@@ -88,8 +92,12 @@ extern void rcu_register_thread(void);
 
 /*
- * Explicit urcu initialization, for "early" use within library constructors.
+ * Explicit rcu initialization, for "early" use within library constructors.
  */